namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Naviframe::event_enabled_get() const
{
   Eina_Bool __return_value =  ::elm_obj_naviframe_event_enabled_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Naviframe::event_enabled_set( ::efl::eolian::in_traits<bool>::type enabled) const
{
    ::elm_obj_naviframe_event_enabled_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enabled));
}
inline ::efl::eolian::return_traits<bool>::type Naviframe::content_preserve_on_pop_get() const
{
   Eina_Bool __return_value =  ::elm_obj_naviframe_content_preserve_on_pop_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Naviframe::content_preserve_on_pop_set( ::efl::eolian::in_traits<bool>::type preserve) const
{
    ::elm_obj_naviframe_content_preserve_on_pop_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(preserve));
}
inline ::efl::eolian::return_traits<bool>::type Naviframe::prev_btn_auto_pushed_get() const
{
   Eina_Bool __return_value =  ::elm_obj_naviframe_prev_btn_auto_pushed_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Naviframe::prev_btn_auto_pushed_set( ::efl::eolian::in_traits<bool>::type auto_pushed) const
{
    ::elm_obj_naviframe_prev_btn_auto_pushed_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(auto_pushed));
}
inline ::efl::eolian::return_traits<  ::efl::eina::list< ::elm::widget::Item>>::type Naviframe::items_get() const
{
   Eina_List * __return_value =  ::elm_obj_naviframe_items_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::top_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_top_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::bottom_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_bottom_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Naviframe::item_pop() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_naviframe_item_pop(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::item_insert_before( ::efl::eolian::in_traits< ::elm::widget::Item>::type before,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type title_label,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type prev_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type next_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type content,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type item_style) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_item_insert_before(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Widget_Item*,  ::efl::eolian::in_traits< ::elm::widget::Item>::type>(before)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(title_label)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(prev_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(next_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(content)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(item_style));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::item_push( ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type title_label,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type prev_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type next_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type content,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type item_style) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_item_push(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(title_label)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(prev_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(next_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(content)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(item_style));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Naviframe::item_simple_promote( ::efl::eolian::in_traits< ::efl::canvas::Object>::type content) const
{
    ::elm_obj_naviframe_item_simple_promote(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(content));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::item_insert_after( ::efl::eolian::in_traits< ::elm::widget::Item>::type after,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type title_label,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type prev_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type next_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type content,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type item_style) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_item_insert_after(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Widget_Item*,  ::efl::eolian::in_traits< ::elm::widget::Item>::type>(after)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(title_label)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(prev_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(next_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(content)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(item_style));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Naviframe::event_enabled_get() const
{
   Eina_Bool __return_value =  ::elm_obj_naviframe_event_enabled_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Naviframe::event_enabled_set( ::efl::eolian::in_traits<bool>::type enabled) const
{
    ::elm_obj_naviframe_event_enabled_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enabled));
}
inline ::efl::eolian::return_traits<bool>::type Naviframe::content_preserve_on_pop_get() const
{
   Eina_Bool __return_value =  ::elm_obj_naviframe_content_preserve_on_pop_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Naviframe::content_preserve_on_pop_set( ::efl::eolian::in_traits<bool>::type preserve) const
{
    ::elm_obj_naviframe_content_preserve_on_pop_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(preserve));
}
inline ::efl::eolian::return_traits<bool>::type Naviframe::prev_btn_auto_pushed_get() const
{
   Eina_Bool __return_value =  ::elm_obj_naviframe_prev_btn_auto_pushed_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Naviframe::prev_btn_auto_pushed_set( ::efl::eolian::in_traits<bool>::type auto_pushed) const
{
    ::elm_obj_naviframe_prev_btn_auto_pushed_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(auto_pushed));
}
inline ::efl::eolian::return_traits<  ::efl::eina::list< ::elm::widget::Item>>::type Naviframe::items_get() const
{
   Eina_List * __return_value =  ::elm_obj_naviframe_items_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::top_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_top_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::bottom_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_bottom_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Naviframe::item_pop() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_naviframe_item_pop(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::item_insert_before( ::efl::eolian::in_traits< ::elm::widget::Item>::type before,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type title_label,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type prev_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type next_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type content,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type item_style) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_item_insert_before(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Widget_Item*,  ::efl::eolian::in_traits< ::elm::widget::Item>::type>(before)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(title_label)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(prev_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(next_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(content)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(item_style));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::item_push( ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type title_label,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type prev_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type next_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type content,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type item_style) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_item_push(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(title_label)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(prev_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(next_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(content)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(item_style));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Naviframe::item_simple_promote( ::efl::eolian::in_traits< ::efl::canvas::Object>::type content) const
{
    ::elm_obj_naviframe_item_simple_promote(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(content));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Naviframe::item_insert_after( ::efl::eolian::in_traits< ::elm::widget::Item>::type after,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type title_label,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type prev_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type next_btn,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type content,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type item_style) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_naviframe_item_insert_after(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Widget_Item*,  ::efl::eolian::in_traits< ::elm::widget::Item>::type>(after)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(title_label)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(prev_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(next_btn)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(content)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(item_style));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline elm::Naviframe::operator ::elm::Naviframe() const { return *static_cast< ::elm::Naviframe const*>(static_cast<void const*>(this)); }
inline elm::Naviframe::operator ::elm::Naviframe&() { return *static_cast< ::elm::Naviframe*>(static_cast<void*>(this)); }
inline elm::Naviframe::operator ::elm::Naviframe const&() const { return *static_cast< ::elm::Naviframe const*>(static_cast<void const*>(this)); }
} }

